@@ -1,13 +1,25 @@
-time_units <- function() c(
-  'ns' = 1e-9,
-  'us' = 1e-6,
-  if (is_utf8_output()) c('\U00B5s' = 1e-6),
-  'ms' = 1e-3,
-  's' = 1,
-  'm' = 60,
-  'h' = 60 * 60,
-  'd' = 60 * 60 * 24,
-  'w' = 60 * 60 * 24 * 7)
+time_units <- function() {
+  stats::setNames(
+    c(1e-9,
+      1e-6,
+      if (is_utf8_output()) 1e-6,
+      1e-3,
+      1,
+      60,
+      60 * 60,
+      60 * 60 * 24,
+      60 * 60 * 24 * 7),
+    c("ns",
+      "us",
+      if (is_utf8_output()) "\U00B5s",
+      "ms",
+      "s",
+      "m",
+      "h",
+      "d",
+      "w")
+  )
+}
 
 #' Human readable times
 #'
@@ -18,25 +30,20 @@ time_units <- function() c(
 #' @param x A numeric or character vector. Character representations can use
 #'   shorthand sizes (see examples).
 #' @examples
-#' bench_time("1")
-#' bench_time("1ns")
-#' bench_time("1us")
-#' bench_time("1ms")
-#' bench_time("1s")
+#' as_bench_time("1ns")
+#' as_bench_time("1")
+#' as_bench_time("1us")
+#' as_bench_time("1ms")
+#' as_bench_time("1s")
 #'
-#' bench_time("100ns") < "1ms"
+#' as_bench_time("100ns") < "1ms"
 #'
-#' sum(bench_time(c("1MB", "5MB", "500KB")))
-#' @name bench_time
+#' sum(as_bench_time(c("1MB", "5MB", "500KB")))
 #' @export
 as_bench_time <- function(x) {
   UseMethod("as_bench_time")
 }
 
-#' @export
-#' @rdname bench_time
-bench_time <- as_bench_time
-
 new_bench_time <- function(x) {
   structure(x, class = c("bench_time", "numeric"))
 }
@@ -216,8 +223,8 @@ scale_type.bench_time <- function(x) "bench_time"
 
 #' Position scales for bench_time data
 #'
-#' Default scales for the [bench_time] class, these are added to plots using
-#' [bench_time] objects automatically.
+#' Default scales for the `bench_time` class, these are added to plots using
+#' `bench_time` objects automatically.
 #' @name scale_bench_time
 #' @param base The base of the logarithm, if `NULL` instead use a
 #'   non-logarithmic scale.
