@@ -182,7 +182,11 @@ describe("unnest.bench_mark", {
   it("does not contain result or memory columns", {
     skip_if_not_installed("tidyr")
     bnch <- mark(1+1, 2+0)
-    res <- tidyr::unnest(bnch)
+    if (tidyr_new_interface()) {
+      res <- tidyr::unnest(bnch, c(time, gc))
+    } else {
+      res <- tidyr::unnest(bnch)
+    }
 
     gc_cols <- colnames(bnch$gc[[1]])
 
